logistic: Logistic Regression Function

Description Usage Arguments Value

View source: R/logistic.R

Description

Logistic Regression Function

Usage

1
logistic(event.e, event.c, n.e, n.c, covar)

Arguments

event.e

is a vector containing the number of events in the treatment group

event.c

is a vector containing the number of events in the control group

n.e

is a vector containing the number of observations in the treatment group

n.c

is a vector containing the number of observations in the control group

covar

is a vector containing covariate values

Value

logistic meta-regression output


andersonb97/metaz documentation built on Dec. 31, 2020, 7:46 p.m.