Description Usage Arguments Value
Logistic Regression Function
1 | logistic(event.e, event.c, n.e, n.c, covar)
|
event.e |
is a vector containing the number of events in the treatment group |
event.c |
is a vector containing the number of events in the control group |
n.e |
is a vector containing the number of observations in the treatment group |
n.c |
is a vector containing the number of observations in the control group |
covar |
is a vector containing covariate values |
logistic meta-regression output
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.